@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::Prereqs::EnsurePP;
 
-our $DATE = '2016-02-19'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-31'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP'; # DIST
+our $VERSION = '0.100'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,7 +26,7 @@ sub setup_installer {
     $self->log(["Listing prereqs ..."]);
     my $res = call_lcpan_script(argv=>[
         "deps", "-R",
-        grep {$_ ne 'perl'} keys %$rr_prereqs]);
+        grep {$_ ne 'perl'} map {("--module", "$_")} keys %$rr_prereqs]);
     my $has_err;
     for my $entry (@$res) {
         my $mod = $entry->{module};
@@ -60,7 +62,7 @@ Dist::Zilla::Plugin::Prereqs::EnsurePP - Make sure that prereqs (and their deps)
 
 =head1 VERSION
 
-This document describes version 0.09 of Dist::Zilla::Plugin::Prereqs::EnsurePP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2016-02-19.
+This document describes version 0.100 of Dist::Zilla::Plugin::Prereqs::EnsurePP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2021-05-31.
 
 =head1 SYNOPSIS
 
@@ -76,13 +78,6 @@ be installed during build time and they all must be indexed by CPAN. Also, a
 reasonably fresh local CPAN mirror indexed (produced by L<App::lcpan>) is
 required.
 
-I need this when building a dist that needs to be included in a fatpacked
-script.
-
-Note: I put this plugin in setup_installer phase instead of before_release
-because I don't always use "dzil release" (i.e. during offline deployment, I
-"dzil build" and "pause upload" separately.)
-
 =for Pod::Coverage .+
 
 =head1 HOMEPAGE
@@ -103,15 +98,12 @@ feature.
 
 =head1 SEE ALSO
 
-L<App::FatPacker>, L<App::depak>
-
 L<Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP>
 
-Related plugins: L<Dist::Zilla::Plugin::CheckPrereqsIndexed>,
-L<Dist::Zilla::Plugin::EnsurePrereqsInstalled>,
-L<Dist::Zilla::Plugin::OnlyCorePrereqs>
+L<Dist::Zilla::Plugin::Prereqs::EnsureCore>
 
-L<App::lcpan>, L<lcpan>
+L<Dist::Zilla::Plugin::CheckPrereqsIndexed>,
+L<Dist::Zilla::Plugin::EnsurePrereqsInstalled>
 
 =head1 AUTHOR
 
@@ -119,7 +111,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
